@@ -7,7 +7,7 @@ module Nanoc
     gem_info = defined?(Gem) ? "with RubyGems #{Gem::VERSION}" : 'without RubyGems'
     engine   = defined?(RUBY_ENGINE) ? RUBY_ENGINE : 'ruby'
     res = ''
-    res << "Nanoc #{Nanoc::VERSION} © 2007-2016 Denis Defreyne.\n"
+    res << "Nanoc #{Nanoc::VERSION} © 2007-2017 Denis Defreyne.\n"
     res << "Running #{engine} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} #{gem_info}.\n"
     res
   end
@@ -27,11 +27,13 @@ require 'ref'
 # Load general requirements
 require 'digest'
 require 'enumerator'
+require 'fiber'
 require 'fileutils'
 require 'forwardable'
 require 'pathname'
 require 'pstore'
 require 'set'
+require 'singleton'
 require 'tempfile'
 require 'thread'
 require 'time'
@@ -41,6 +43,8 @@ require 'English'
 # Load Nanoc
 require 'nanoc/version'
 require 'nanoc/base'
+require 'nanoc/checking'
+require 'nanoc/deploying'
 require 'nanoc/extra'
 require 'nanoc/data_sources'
 require 'nanoc/filters'
