@@ -3,6 +3,8 @@ module Nanoc::Int
   #
   # @api private
   class CodeSnippet
+    include Nanoc::Int::ContractsSupport
+
     # A string containing the actual code in this code snippet.
     #
     # @return [String]
@@ -13,6 +15,7 @@ module Nanoc::Int
     # @return [String]
     attr_reader :filename
 
+    contract String, String => C::Any
     # Creates a new code snippet.
     #
     # @param [String] data The raw source code which will be executed before
@@ -24,11 +27,13 @@ module Nanoc::Int
       @filename = filename
     end
 
+    contract C::None => nil
     # Loads the code by executing it.
     #
     # @return [void]
     def load
       eval(@data, TOPLEVEL_BINDING, @filename)
+      nil
     end
 
     # Returns an object that can be used for uniquely identifying objects.
