@@ -33,11 +33,21 @@ module Nanoc::Int
       string_pattern_type: 'glob',
     }.freeze
 
-    contract Hash => C::Any
+    # @return [String, nil] The active environment for the configuration
+    attr_reader :env_name
+
+    # Configuration environments property key
+    ENVIRONMENTS_CONFIG_KEY = :environments
+    NANOC_ENV = 'NANOC_ENV'.freeze
+    NANOC_ENV_DEFAULT = 'default'.freeze
+
+    contract C::KeywordArgs[hash: C::Optional[Hash], env_name: C::Maybe[String]] => C::Any
     # Creates a new configuration with the given hash.
     #
     # @param [Hash] hash The actual configuration hash
-    def initialize(hash = {})
+    # @param [String, nil] env_name The active environment for this configuration
+    def initialize(hash: {}, env_name: nil)
+      @env_name = env_name
       @wrapped = hash.__nanoc_symbolize_keys_recursively
     end
 
@@ -48,7 +58,19 @@ module Nanoc::Int
         DEFAULT_DATA_SOURCE_CONFIG.merge(ds)
       end
 
-      self.class.new(new_wrapped)
+      self.class.new(hash: new_wrapped)
+    end
+
+    def with_environment
+      return self unless @wrapped.key?(ENVIRONMENTS_CONFIG_KEY)
+
+      # Set active environment
+      env_name = @env_name || ENV.fetch(NANOC_ENV, NANOC_ENV_DEFAULT)
+
+      # Load given environment configuration
+      env_config = @wrapped[ENVIRONMENTS_CONFIG_KEY].fetch(env_name.to_sym, {})
+
+      self.class.new(hash: @wrapped, env_name: env_name).merge(env_config)
     end
 
     contract C::None => Hash
@@ -86,12 +108,12 @@ module Nanoc::Int
 
     contract C::Or[Hash, self] => self
     def merge(hash)
-      self.class.new(@wrapped.merge(hash.to_h))
+      self.class.new(hash: @wrapped.merge(hash.to_h), env_name: @env_name)
     end
 
     contract C::Any => self
     def without(key)
-      self.class.new(@wrapped.reject { |k, _v| k == key })
+      self.class.new(hash: @wrapped.reject { |k, _v| k == key }, env_name: @env_name)
     end
 
     contract C::Any => self
