@@ -5,15 +5,9 @@ module Nanoc
 
       attr_reader :name
 
-      contract Symbol, C::Bool => C::Any
-      def initialize(name, is_final)
+      contract Symbol => C::Any
+      def initialize(name)
         @name = name
-        @is_final = is_final
-      end
-
-      contract C::None => C::Bool
-      def final?
-        @is_final
       end
     end
   end
