@@ -5,5 +5,7 @@ require_relative 'repos/compiled_content_cache'
 require_relative 'repos/config_loader'
 require_relative 'repos/data_source'
 require_relative 'repos/dependency_store'
+require_relative 'repos/item_rep_repo'
+require_relative 'repos/outdatedness_store'
 require_relative 'repos/rule_memory_store'
 require_relative 'repos/site_loader'
