@@ -17,6 +17,10 @@ module Nanoc::Int
       end
 
       Nanoc::Int::ItemRepRouter.new(@reps, @action_provider, @site).run
+
+      @reps.each do |rep|
+        rep.snapshot_defs = @action_provider.snapshots_defs_for(rep)
+      end
     end
   end
 end
