@@ -9,6 +9,12 @@ module Nanoc::Int
       end
     end
 
+    class RouteWithoutSlashError < ::Nanoc::Error
+      def initialize(output_path, rep)
+        super("The item representation #{rep.inspect} is routed to #{output_path}, which does not start with a slash, as required.")
+      end
+    end
+
     def initialize(reps, action_provider, site)
       @reps = reps
       @action_provider = action_provider
@@ -18,18 +24,21 @@ module Nanoc::Int
     def run
       paths_to_reps = {}
       @reps.each do |rep|
-        mem = @action_provider.memory_for(rep)
-        mem.snapshot_actions.each do |snapshot_action|
-          route_rep(rep, snapshot_action, paths_to_reps)
+        @action_provider.paths_for(rep).each do |snapshot_name, path|
+          route_rep(rep, path, snapshot_name, paths_to_reps)
         end
       end
     end
 
-    def route_rep(rep, snapshot_action, paths_to_reps)
-      basic_path = snapshot_action.path
+    def route_rep(rep, path, snapshot_name, paths_to_reps)
+      basic_path = path
       return if basic_path.nil?
       basic_path = basic_path.encode('UTF-8')
 
+      unless basic_path.start_with?('/')
+        raise RouteWithoutSlashError.new(basic_path, rep)
+      end
+
       # Check for duplicate paths
       if paths_to_reps.key?(basic_path)
         raise IdenticalRoutesError.new(basic_path, paths_to_reps[basic_path], rep)
@@ -37,8 +46,8 @@ module Nanoc::Int
         paths_to_reps[basic_path] = rep
       end
 
-      rep.raw_paths[snapshot_action.snapshot_name] = @site.config[:output_dir] + basic_path
-      rep.paths[snapshot_action.snapshot_name] = strip_index_filename(basic_path)
+      rep.raw_paths[snapshot_name] = @site.config[:output_dir] + basic_path
+      rep.paths[snapshot_name] = strip_index_filename(basic_path)
     end
 
     def strip_index_filename(basic_path)
