@@ -5,6 +5,7 @@ module Nanoc
       @context = context
     end
 
+    # @api private
     def _context
       @context
     end
@@ -22,5 +23,9 @@ module Nanoc
     def frozen?
       unwrap.frozen?
     end
+
+    def inspect
+      "<#{self.class}>"
+    end
   end
 end
