@@ -4,13 +4,13 @@ module Nanoc
     attr_reader :reps
     attr_reader :items
     attr_reader :dependency_tracker
-    attr_reader :compiler
+    attr_reader :compilation_context
 
-    def initialize(reps:, items:, dependency_tracker:, compiler:)
+    def initialize(reps:, items:, dependency_tracker:, compilation_context:)
       @reps = reps
       @items = items
       @dependency_tracker = dependency_tracker
-      @compiler = compiler
+      @compilation_context = compilation_context
     end
   end
 end
