@@ -19,8 +19,6 @@ module Nanoc::CLI
   autoload 'ErrorHandler',        'nanoc/cli/error_handler'
 
   # @return [Boolean] true if debug output is enabled, false if not
-  #
-  # @since 3.2.0
   def self.debug?
     @debug || false
   end
@@ -29,8 +27,6 @@ module Nanoc::CLI
   #   false if it should not
   #
   # @return [void]
-  #
-  # @since 3.2.0
   def self.debug=(boolean)
     @debug = boolean
   end
@@ -103,6 +99,17 @@ module Nanoc::CLI
       cmd = load_command_at(cmd_filename)
       add_command(cmd)
     end
+
+    if defined?(Bundler)
+      # Discover external commands through Bundler
+      begin
+        Bundler.require(:nanoc)
+      rescue Bundler::GemfileNotFound
+        # When running nanoc with Bundler being defined but
+        # no gemfile being present (rubygems automatically loads
+        # Bundler when executing from command line), don't crash.
+      end
+    end
   end
 
   # Loads site-specific commands.
