@@ -2,19 +2,8 @@ usage 'compile [options]'
 summary 'compile items of this site'
 description <<-EOS
 Compile all items of the current site.
-
-The compile command will show all items of the site as they are processed. The time spent compiling the item will be printed, as well as a status message, which can be one of the following:
-
-CREATED - The compiled item did not yet exist and has been created
-
-UPDATED - The compiled item did already exist and has been modified
-
-IDENTICAL - The item was deemed outdated and has been recompiled, but the compiled version turned out to be identical to the already existing version
-
-SKIP - The item was deemed not outdated and was therefore not recompiled
-
 EOS
-flag nil, :profile, 'profile compilation' if Nanoc::Feature.enabled?('PROFILER')
+flag nil, :profile, 'profile compilation' if Nanoc::Feature.enabled?(Nanoc::Feature::PROFILER)
 
 module Nanoc::CLI::Commands
   class Compile < ::Nanoc::CLI::CommandRunner
@@ -24,8 +13,7 @@ module Nanoc::CLI::Commands
     #
     # @abstract Subclasses must override {#start} and may override {#stop}.
     class Listener
-      def initialize(*)
-      end
+      def initialize(*); end
 
       # @param [Nanoc::CLI::CommandRunner] command_runner The command runner for this listener
       #
@@ -48,8 +36,7 @@ module Nanoc::CLI::Commands
       # Stops the listener. The default implementation removes self from all notification center observers.
       #
       # @return [void]
-      def stop
-      end
+      def stop; end
 
       # @api private
       def start_safely
@@ -164,19 +151,55 @@ module Nanoc::CLI::Commands
 
       # @param [Enumerable<Nanoc::Int::ItemRep>] reps
       def initialize(reps:)
-        @times = {}
+        # rep ->
+        #   filter_name ->
+        #     accum -> 0.0
+        #     last_start -> nil
+        @times_per_rep = {}
 
         @reps = reps
       end
 
       # @see Listener#start
       def start
-        Nanoc::Int::NotificationCenter.on(:filtering_started) do |_rep, filter_name|
-          @times[filter_name] ||= []
-          @times[filter_name] << { start: Time.now }
+        Nanoc::Int::NotificationCenter.on(:filtering_started) do |rep, filter_name|
+          @times_per_rep[rep] ||= {}
+          @times_per_rep[rep][filter_name] ||= {}
+
+          @times_per_rep[rep][filter_name][:last_start] = Time.now
+          @times_per_rep[rep][filter_name][:accum] ||= []
+          @times_per_rep[rep][filter_name][:suspended] = false
         end
-        Nanoc::Int::NotificationCenter.on(:filtering_ended) do |_rep, filter_name|
-          @times[filter_name].last[:stop] = Time.now
+
+        Nanoc::Int::NotificationCenter.on(:filtering_ended) do |rep, filter_name|
+          times = @times_per_rep[rep][filter_name]
+          last_start = @times_per_rep[rep][filter_name][:last_start]
+
+          times[:accum] << (Time.now - last_start)
+          @times_per_rep[rep][filter_name].delete(:last_start)
+        end
+
+        Nanoc::Int::NotificationCenter.on(:compilation_suspended) do |rep, _exception|
+          @times_per_rep.fetch(rep, {}).each do |_filter_name, times|
+            if times[:last_start]
+              times[:accum] << (Time.now - times[:last_start])
+              times.delete(:last_start)
+              times[:suspended] = true
+
+              break
+            end
+          end
+        end
+
+        Nanoc::Int::NotificationCenter.on(:compilation_started) do |rep|
+          @times_per_rep.fetch(rep, {}).each do |filter_name, times|
+            if times[:suspended]
+              @times_per_rep[rep][filter_name][:last_start] = Time.now
+              times[:suspended] = false
+
+              break
+            end
+          end
         end
       end
 
@@ -217,7 +240,7 @@ module Nanoc::CLI::Commands
         # Calculate stats
         count = samples.size
         min   = samples.min
-        tot   = samples.reduce(0) { |a, e| a + e }
+        tot   = samples.reduce(0) { |acc, elem| acc + elem }
         avg   = tot / count
         max   = samples.max
 
@@ -236,55 +259,17 @@ module Nanoc::CLI::Commands
       def durations_per_filter
         @_durations_per_filter ||= begin
           result = {}
-          @times.keys.each do |filter_name|
-            durations = durations_for_filter(filter_name)
-            if durations
-              result[filter_name] = durations
+
+          @times_per_rep.each do |_rep, times_per_filter|
+            times_per_filter.each do |filter_name, data|
+              result[filter_name] ||= []
+              result[filter_name].concat(data[:accum])
             end
           end
+
           result
         end
       end
-
-      def durations_for_filter(filter_name)
-        result = []
-        @times[filter_name].each do |sample|
-          if sample[:start] && sample[:stop]
-            result << sample[:stop] - sample[:start]
-          end
-        end
-        result
-      end
-    end
-
-    # Controls garbage collection so that it only occurs once every 20 items
-    class GCController < Listener
-      # @see Listener#enable_for?
-      def self.enable_for?(_command_runner)
-        !ENV.key?('TRAVIS')
-      end
-
-      def initialize(*)
-        @gc_count = 0
-      end
-
-      # @see Listener#start
-      def start
-        Nanoc::Int::NotificationCenter.on(:compilation_started) do |_rep|
-          if @gc_count % 20 == 0
-            GC.enable
-            GC.start
-            GC.disable
-          end
-          @gc_count += 1
-        end
-      end
-
-      # @see Listener#stop
-      def stop
-        super
-        GC.enable
-      end
     end
 
     # Prints debug information (compilation started/ended, filtering started/ended, …)
@@ -303,7 +288,7 @@ module Nanoc::CLI::Commands
           puts "*** Ended compilation of #{rep.inspect}"
           puts
         end
-        Nanoc::Int::NotificationCenter.on(:compilation_failed) do |rep, e|
+        Nanoc::Int::NotificationCenter.on(:compilation_suspended) do |rep, e|
           puts "*** Suspended compilation of #{rep.inspect}: #{e.message}"
         end
         Nanoc::Int::NotificationCenter.on(:cached_content_used) do |rep|
@@ -325,17 +310,26 @@ module Nanoc::CLI::Commands
     class FileActionPrinter < Listener
       def initialize(reps:)
         @start_times = {}
+        @acc_durations = {}
 
         @reps = reps
       end
 
       # @see Listener#start
       def start
-        Nanoc::Int::NotificationCenter.on(:compilation_started) do |rep|
-          @start_times[rep.raw_path] = Time.now
+        Nanoc::Int::NotificationCenter.on(:compilation_started, self) do |rep|
+          @start_times[rep] = Time.now
+          @acc_durations[rep] ||= 0.0
         end
-        Nanoc::Int::NotificationCenter.on(:rep_written) do |_rep, path, is_created, is_modified|
-          duration = path && @start_times[path] ? Time.now - @start_times[path] : nil
+
+        Nanoc::Int::NotificationCenter.on(:compilation_suspended, self) do |rep|
+          @acc_durations[rep] += Time.now - @start_times[rep]
+        end
+
+        Nanoc::Int::NotificationCenter.on(:rep_written, self) do |rep, path, is_created, is_modified|
+          @acc_durations[rep] += Time.now - @start_times[rep]
+          duration = @acc_durations[rep]
+
           action =
             if is_created then :create
             elsif is_modified then :update
@@ -353,6 +347,11 @@ module Nanoc::CLI::Commands
       # @see Listener#stop
       def stop
         super
+
+        Nanoc::Int::NotificationCenter.remove(:compilation_started, self)
+        Nanoc::Int::NotificationCenter.remove(:compilation_suspended, self)
+        Nanoc::Int::NotificationCenter.remove(:rep_written, self)
+
         @reps.select { |r| !r.compiled? }.each do |rep|
           rep.raw_paths.each do |_snapshot_name, raw_path|
             log(:low, :skip, raw_path, nil)
@@ -404,7 +403,6 @@ module Nanoc::CLI::Commands
       puts 'Compiling site…'
       run_listeners_while do
         site.compile
-        prune
       end
 
       time_after = Time.now
@@ -414,20 +412,13 @@ module Nanoc::CLI::Commands
 
     protected
 
-    def prune
-      if site.config[:prune][:auto_prune]
-        Nanoc::Extra::Pruner.new(site, exclude: prune_config_exclude).run
-      end
-    end
-
     def default_listener_classes
       [
+        Nanoc::CLI::Commands::Compile::StackProfProfiler,
         Nanoc::CLI::Commands::Compile::DiffGenerator,
         Nanoc::CLI::Commands::Compile::DebugPrinter,
         Nanoc::CLI::Commands::Compile::TimingRecorder,
-        Nanoc::CLI::Commands::Compile::GCController,
         Nanoc::CLI::Commands::Compile::FileActionPrinter,
-        Nanoc::CLI::Commands::Compile::StackProfProfiler,
       ]
     end
 
@@ -452,20 +443,12 @@ module Nanoc::CLI::Commands
     end
 
     def teardown_listeners
-      @listeners.each(&:stop_safely)
+      @listeners.reverse_each(&:stop_safely)
     end
 
     def reps
       site.compiler.reps
     end
-
-    def prune_config
-      site.config[:prune] || {}
-    end
-
-    def prune_config_exclude
-      prune_config[:exclude] || {}
-    end
   end
 end
 
