@@ -1,4 +1,4 @@
-usage 'deploy [options]'
+usage 'deploy [target] [options]'
 summary 'deploy the compiled site'
 description "
 Deploys the compiled site. The compiled site contents in the output directory will be uploaded to the destination, which is specified using the `--target` option.
@@ -27,7 +27,7 @@ module Nanoc::CLI::Commands
     private
 
     def list_deployers
-      deployers      = Nanoc::Int::PluginRegistry.instance.find_all(Nanoc::Extra::Deployer)
+      deployers      = Nanoc::Int::PluginRegistry.instance.find_all(Nanoc::Deploying::Deployer)
       deployer_names = deployers.keys.sort_by(&:to_s)
       puts 'Available deployers:'
       deployer_names.each do |name|
@@ -60,10 +60,19 @@ module Nanoc::CLI::Commands
         raise Nanoc::Int::Errors::GenericTrivial, 'The site has no deployment configurations.'
       end
 
-      target = options.fetch(:target, :default).to_sym
-      deploy_configs.fetch(target) do
-        # FIXME: target name is unobvious
-        raise Nanoc::Int::Errors::GenericTrivial, "The site has no deployment configuration for #{target}."
+      if arguments.length > 1
+        raise Nanoc::Int::Errors::GenericTrivial, "usage: #{command.usage}"
+      end
+
+      target_from_arguments = arguments[0]
+      target_from_options = options.fetch(:target, nil)
+      if target_from_arguments && target_from_options
+        raise Nanoc::Int::Errors::GenericTrivial, 'Only one deployment target can be specified on the command line.'
+      end
+
+      target = target_from_arguments || target_from_options || :default
+      deploy_configs.fetch(target.to_sym) do
+        raise Nanoc::Int::Errors::GenericTrivial, "The site has no deployment configuration named `#{target}`."
       end
     end
 
@@ -76,7 +85,7 @@ module Nanoc::CLI::Commands
     end
 
     def check
-      runner = Nanoc::Extra::Checking::Runner.new(site)
+      runner = Nanoc::Checking::Runner.new(site)
       if runner.dsl_present?
         puts 'Running issue checks…'
         is_success = runner.run_for_deploy
@@ -96,13 +105,13 @@ module Nanoc::CLI::Commands
     end
 
     def deployer_class_for_config(config)
-      names = Nanoc::Extra::Deployer.all.keys
+      names = Nanoc::Deploying::Deployer.all.keys
       name = config.fetch(:kind) do
         $stderr.puts 'Warning: The specified deploy target does not have a kind attribute. Assuming rsync.'
         'rsync'
       end
 
-      deployer_class = Nanoc::Extra::Deployer.named(name)
+      deployer_class = Nanoc::Deploying::Deployer.named(name)
       if deployer_class.nil?
         raise Nanoc::Int::Errors::GenericTrivial, "The specified deploy target has an unrecognised kind “#{name}” (expected one of #{names.join(', ')})."
       end
