@@ -20,6 +20,9 @@ module Nanoc::CLI::Commands
       compiler.load_stores
       dependency_store = compiler.dependency_store
 
+      # Build reps
+      compiler.build_reps
+
       # Print data
       print_item_dependencies(items, dependency_store)
       print_item_rep_paths(items)
@@ -59,11 +62,23 @@ module Nanoc::CLI::Commands
     def print_item_dependencies(items, dependency_store)
       print_header('Item dependencies')
 
+      puts 'Legend:'
+      puts '  r = dependency on raw content'
+      puts '  a = dependency on attributes'
+      puts '  c = dependency on compiled content'
+      puts '  p = dependency on the path'
+      puts
+
       sorted_with_prev(items) do |item, prev|
         puts if prev
         puts "item #{item.identifier} depends on:"
-        predecessors = dependency_store.objects_causing_outdatedness_of(item).sort_by { |i| i ? i.identifier : '' }
-        predecessors.each do |pred|
+        dependencies =
+          dependency_store
+          .dependencies_causing_outdatedness_of(item)
+          .sort_by { |dep| dep.from ? dep.from.identifier : '' }
+        dependencies.each do |dep|
+          pred = dep.from
+
           type =
             case pred
             when Nanoc::Int::Layout
@@ -74,13 +89,19 @@ module Nanoc::CLI::Commands
               'item'
             end
 
+          props = ''
+          props << (dep.props.raw_content? ? 'r' : '_')
+          props << (dep.props.attributes? ? 'a' : '_')
+          props << (dep.props.compiled_content? ? 'c' : '_')
+          props << (dep.props.path? ? 'p' : '_')
+
           if pred
-            puts "  [ #{format '%6s', type} ] #{pred.identifier}"
+            puts "  [ #{format '%6s', type} ] (#{props}) #{pred.identifier}"
           else
             puts '  ( removed item )'
           end
         end
-        puts '  (nothing)' if predecessors.empty?
+        puts '  (nothing)' if dependencies.empty?
       end
     end
 
