@@ -47,12 +47,10 @@ module Nanoc::DataSources
   # @api private
   class Filesystem < Nanoc::DataSource
     # See {Nanoc::DataSource#up}.
-    def up
-    end
+    def up; end
 
     # See {Nanoc::DataSource#down}.
-    def down
-    end
+    def down; end
 
     def content_dir_name
       config.fetch(:content_dir, 'content')
@@ -76,11 +74,12 @@ module Nanoc::DataSources
 
     class ProtoDocument
       attr_reader :attributes
-      attr_reader :checksum_data
+      attr_reader :content_checksum_data
+      attr_reader :attributes_checksum_data
       attr_reader :is_binary
       alias binary? is_binary
 
-      def initialize(is_binary:, content: nil, filename: nil, attributes:, checksum_data: nil)
+      def initialize(is_binary:, content: nil, filename: nil, attributes:, content_checksum_data: nil, attributes_checksum_data: nil)
         if content.nil? && filename.nil?
           raise ArgumentError, '#initialize needs at least content or filename'
         end
@@ -89,7 +88,8 @@ module Nanoc::DataSources
         @content = content
         @filename = filename
         @attributes = attributes
-        @checksum_data = checksum_data
+        @content_checksum_data = content_checksum_data
+        @attributes_checksum_data = attributes_checksum_data
       end
 
       def content
@@ -117,7 +117,7 @@ module Nanoc::DataSources
 
         ProtoDocument.new(is_binary: true, filename: content_filename, attributes: meta)
       elsif is_binary && klass == Nanoc::Int::Layout
-        raise "The layout file '#{content_filename}' is a binary file, but layouts can only be textual"
+        raise Errors::BinaryLayout.new(content_filename)
       else
         parse_result = parse(content_filename, meta_filename)
 
@@ -125,7 +125,8 @@ module Nanoc::DataSources
           is_binary: false,
           content: parse_result.content,
           attributes: parse_result.attributes,
-          checksum_data: "content=#{parse_result.content},meta=#{parse_result.attributes_data}",
+          content_checksum_data: parse_result.content,
+          attributes_checksum_data: parse_result.attributes_data,
         )
       end
     end
@@ -157,23 +158,38 @@ module Nanoc::DataSources
           attributes = attributes_for(proto_doc, content_filename, meta_filename)
           identifier = identifier_for(content_filename, meta_filename, dir_name)
 
-          res << klass.new(content, attributes, identifier, checksum_data: proto_doc.checksum_data)
+          res << klass.new(
+            content,
+            attributes,
+            identifier,
+            content_checksum_data: proto_doc.content_checksum_data,
+            attributes_checksum_data: attributes_checksum_data_for(proto_doc, content_filename, meta_filename),
+          )
         end
       end
 
       res
     end
 
-    def attributes_for(proto_doc, content_filename, meta_filename)
-      extra_attributes = {
+    def attributes_checksum_data_for(proto_doc, content_filename, meta_filename)
+      YAML.dump(
+        attributes: proto_doc.attributes_checksum_data,
+        extra_attributes: extra_attributes_for(content_filename, meta_filename),
+      )
+    end
+
+    def extra_attributes_for(content_filename, meta_filename)
+      {
         filename: content_filename,
         content_filename: content_filename,
         meta_filename: meta_filename,
         extension: content_filename ? ext_of(content_filename)[1..-1] : nil,
         mtime: mtime_of(content_filename, meta_filename),
       }
+    end
 
-      extra_attributes.merge(proto_doc.attributes)
+    def attributes_for(proto_doc, content_filename, meta_filename)
+      extra_attributes_for(content_filename, meta_filename).merge(proto_doc.attributes)
     end
 
     def identifier_for(content_filename, meta_filename, dir_name)
@@ -232,11 +248,11 @@ module Nanoc::DataSources
 
         # Check number of files per type
         unless [0, 1].include?(meta_filenames.size)
-          raise "Found #{meta_filenames.size} meta files for #{basename}; expected 0 or 1"
+          raise Errors::MultipleMetaFiles.new(meta_filenames, basename)
         end
         unless config[:identifier_type] == 'full'
           unless [0, 1].include?(content_filenames.size)
-            raise "Found #{content_filenames.size} content files for #{basename}; expected 0 or 1"
+            raise Errors::MultipleContentFiles.new(meta_filenames, basename)
           end
         end
 
@@ -252,7 +268,7 @@ module Nanoc::DataSources
 
     # Returns all files in the given directory and directories below it.
     def all_files_in(dir_name)
-      Nanoc::Extra::FilesystemTools.all_files_in(dir_name, config[:extra_files])
+      Nanoc::DataSources::Filesystem::Tools.all_files_in(dir_name, config[:extra_files])
     end
 
     # Returns the filename for the given base filename and the extension.
@@ -345,7 +361,7 @@ module Nanoc::DataSources
 
       pieces = data.split(/^(-{5}|-{3})[ \t]*\r?\n?/, 3)
       if pieces.size < 4
-        raise "The file '#{content_filename}' appears to start with a metadata section (three or five dashes at the top) but it does not seem to be in the correct format."
+        raise Errors::InvalidFormat.new(content_filename)
       end
 
       meta = parse_metadata(pieces[2], content_filename)
@@ -358,8 +374,8 @@ module Nanoc::DataSources
     def parse_metadata(data, filename)
       begin
         meta = YAML.load(data) || {}
-      rescue Exception => e
-        raise "Could not parse YAML for #{filename}: #{e.message}"
+      rescue => e
+        raise Errors::UnparseableMetadata.new(filename, e)
       end
 
       verify_meta(meta, filename)
@@ -379,16 +395,10 @@ module Nanoc::DataSources
       end
     end
 
-    class InvalidMetadataError < Nanoc::Error
-      def initialize(filename, klass)
-        super("The file #{filename} has invalid metadata (expected key-value pairs, found #{klass} instead)")
-      end
-    end
-
     def verify_meta(meta, filename)
       return if meta.is_a?(Hash)
 
-      raise InvalidMetadataError.new(filename, meta.class)
+      raise Errors::InvalidMetadata.new(filename, meta.class)
     end
 
     # Reads the content of the file with the given name and returns a string
@@ -400,7 +410,7 @@ module Nanoc::DataSources
       begin
         data = File.read(filename)
       rescue => e
-        raise "Could not read #{filename}: #{e.inspect}"
+        raise Errors::FileUnreadable.new(filename, e)
       end
 
       # Fix
@@ -415,11 +425,11 @@ module Nanoc::DataSources
         begin
           data.encode!('UTF-8')
         rescue
-          raise_encoding_error(filename, original_encoding)
+          raise Errors::InvalidEncoding.new(filename, original_encoding)
         end
 
         unless data.valid_encoding?
-          raise_encoding_error(filename, original_encoding)
+          raise Errors::InvalidEncoding.new(filename, original_encoding)
         end
       end
 
@@ -428,10 +438,8 @@ module Nanoc::DataSources
 
       data
     end
-
-    # Raises an invalid encoding error for the given filename and encoding.
-    def raise_encoding_error(filename, encoding)
-      raise "Could not read #{filename} because the file is not valid #{encoding}."
-    end
   end
 end
+
+require_relative 'filesystem/tools'
+require_relative 'filesystem/errors'
