@@ -1,6 +1,5 @@
-# encoding: utf-8
-
 module Nanoc::Filters
+  # @api private
   class ERB < Nanoc::Filter
     requires 'erb'
 
@@ -8,10 +7,10 @@ module Nanoc::Filters
     #
     # @param [String] content The content to filter
     #
-    # @option params [Integer] safe_level (nil) The safe level (`$SAFE`) to
+    # @option params [Integer] :safe_level (nil) The safe level (`$SAFE`) to
     #   use while running this filter
     #
-    # @option params [String] trim_mode (nil) The trim mode to use
+    # @option params [String] :trim_mode (nil) The trim mode to use
     #
     # @return [String] The filtered content
     def run(content, params = {})
@@ -19,7 +18,7 @@ module Nanoc::Filters
       assigns.merge!(params[:locals] || {})
 
       # Create context
-      context = ::Nanoc::Context.new(assigns)
+      context = ::Nanoc::Int::Context.new(assigns)
 
       # Get binding
       proc = assigns[:content] ? -> { assigns[:content] } : nil
