@@ -1,6 +1,4 @@
 module Nanoc::Filters
-  # @since 3.2.0
-  #
   # @api private
   class Mustache < Nanoc::Filter
     requires 'mustache'
@@ -13,7 +11,7 @@ module Nanoc::Filters
     #
     # @return [String] The filtered content
     def run(content, _params = {})
-      context = item.attributes.merge({ yield: assigns[:content] })
+      context = item.attributes.merge(yield: assigns[:content])
       ::Mustache.render(content, context)
     end
   end
