@@ -1,3 +1,5 @@
+require 'helper'
+
 class Nanoc::Int::CompilerTest < Nanoc::TestCase
   def new_compiler(site = nil)
     site ||= Nanoc::Int::Site.new(
@@ -11,15 +13,18 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
 
     action_provider = Nanoc::Int::ActionProvider.named(:rule_dsl).for(site)
 
+    objects = site.items.to_a + site.layouts.to_a
+
     params = {
-      compiled_content_cache: Nanoc::Int::CompiledContentCache.new,
-      checksum_store: Nanoc::Int::ChecksumStore.new(site: site),
+      compiled_content_cache: Nanoc::Int::CompiledContentCache.new(items: site.items),
+      checksum_store: Nanoc::Int::ChecksumStore.new(site: site, objects: objects),
       rule_memory_store: Nanoc::Int::RuleMemoryStore.new,
       dependency_store: Nanoc::Int::DependencyStore.new(
         site.items.to_a + site.layouts.to_a,
       ),
       action_provider: action_provider,
       reps: reps,
+      outdatedness_store: Nanoc::Int::OutdatednessStore.new(site: site, reps: reps),
     }
 
     params[:outdatedness_checker] =
@@ -208,21 +213,6 @@ class Nanoc::Int::CompilerTest < Nanoc::TestCase
     end
   end
 
-  def test_compile_should_recompile_all_reps
-    Nanoc::CLI.run %w(create_site bar)
-
-    FileUtils.cd('bar') do
-      Nanoc::CLI.run %w(compile)
-
-      site = Nanoc::Int::SiteLoader.new.new_from_cwd
-      site.compile
-
-      # At this point, even the already compiled items in the previous pass
-      # should have their compiled content assigned, so this should work:
-      site.compiler.reps[site.items['/index.*']][0].compiled_content
-    end
-  end
-
   def test_disallow_multiple_snapshots_with_the_same_name
     # Create site
     Nanoc::CLI.run %w(create_site bar)
