@@ -1,7 +1,12 @@
+require 'helper'
+
 class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
   def test_initialize
     # Mock items
-    items = [mock, mock]
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -13,7 +18,10 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_record_dependency
     # Mock items
-    items = [mock, mock]
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -27,7 +35,10 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_record_dependency_no_self
     # Mock items
-    items = [mock, mock]
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -42,7 +53,10 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_record_dependency_no_doubles
     # Mock items
-    items = [mock, mock]
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -58,7 +72,11 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_objects_causing_outdatedness_of
     # Mock items
-    items = [mock, mock, mock]
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+      Nanoc::Int::Item.new('c', {}, '/c.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -71,44 +89,14 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
     assert_contains_exactly [items[1]], store.objects_causing_outdatedness_of(items[0])
   end
 
-  def test_objects_outdated_due_to
-    # Mock items
-    items = [mock, mock, mock]
-
-    # Create
-    store = Nanoc::Int::DependencyStore.new(items)
-
-    # Record some dependencies
-    store.record_dependency(items[0], items[1])
-    store.record_dependency(items[1], items[2])
-
-    # Verify dependencies
-    assert_contains_exactly [items[0]], store.objects_outdated_due_to(items[1])
-  end
-
-  def test_enter_and_exit
-    items = [mock, mock]
-
-    store = Nanoc::Int::DependencyStore.new(items)
-    tracker = Nanoc::Int::DependencyTracker.new(store)
-
-    tracker.enter(items[0])
-    tracker.enter(items[1])
-    tracker.exit(items[1])
-    tracker.exit(items[0])
-
-    assert_contains_exactly [items[1]], store.objects_causing_outdatedness_of(items[0])
-    assert_empty store.objects_causing_outdatedness_of(items[1])
-  end
-
   def test_store_graph_and_load_graph_simple
     # Mock items
-    items = [mock('0'), mock('1'), mock('2'), mock('3')]
-    items.each { |i| i.stubs(:type).returns(:item) }
-    items[0].stubs(:reference).returns([:item, '/aaa/'])
-    items[1].stubs(:reference).returns([:item, '/bbb/'])
-    items[2].stubs(:reference).returns([:item, '/ccc/'])
-    items[3].stubs(:reference).returns([:item, '/ddd/'])
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+      Nanoc::Int::Item.new('c', {}, '/c.md'),
+      Nanoc::Int::Item.new('d', {}, '/d.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -137,12 +125,12 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_store_graph_and_load_graph_with_removed_items
     # Mock items
-    items = [mock('0'), mock('1'), mock('2'), mock('3')]
-    items.each { |i| i.stubs(:type).returns(:item) }
-    items[0].stubs(:reference).returns([:item, '/aaa/'])
-    items[1].stubs(:reference).returns([:item, '/bbb/'])
-    items[2].stubs(:reference).returns([:item, '/ccc/'])
-    items[3].stubs(:reference).returns([:item, '/ddd/'])
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+      Nanoc::Int::Item.new('c', {}, '/c.md'),
+      Nanoc::Int::Item.new('d', {}, '/d.md'),
+    ]
 
     # Create new and old lists
     old_items = [items[0], items[1], items[2], items[3]]
@@ -174,11 +162,11 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_store_graph_with_nils_in_dst
     # Mock items
-    items = [mock('0'), mock('1'), mock('2')]
-    items.each { |i| i.stubs(:type).returns(:item) }
-    items[0].stubs(:reference).returns([:item, '/aaa/'])
-    items[1].stubs(:reference).returns([:item, '/bbb/'])
-    items[2].stubs(:reference).returns([:item, '/ccc/'])
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+      Nanoc::Int::Item.new('c', {}, '/c.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -204,11 +192,11 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_store_graph_with_nils_in_src
     # Mock items
-    items = [mock('0'), mock('1'), mock('2')]
-    items.each { |i| i.stubs(:type).returns(:item) }
-    items[0].stubs(:reference).returns([:item, '/aaa/'])
-    items[1].stubs(:reference).returns([:item, '/bbb/'])
-    items[2].stubs(:reference).returns([:item, '/ccc/'])
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+      Nanoc::Int::Item.new('c', {}, '/c.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
@@ -234,7 +222,11 @@ class Nanoc::Int::DependencyTrackerTest < Nanoc::TestCase
 
   def test_forget_dependencies_for
     # Mock items
-    items = [mock, mock, mock]
+    items = [
+      Nanoc::Int::Item.new('a', {}, '/a.md'),
+      Nanoc::Int::Item.new('b', {}, '/b.md'),
+      Nanoc::Int::Item.new('c', {}, '/c.md'),
+    ]
 
     # Create
     store = Nanoc::Int::DependencyStore.new(items)
