@@ -1,3 +1,5 @@
+require 'helper'
+
 class Nanoc::CLI::Commands::CreateSiteTest < Nanoc::TestCase
   def test_create_site_with_existing_name
     Nanoc::CLI.run %w(create_site foo)
@@ -75,7 +77,7 @@ class Nanoc::CLI::Commands::CreateSiteTest < Nanoc::TestCase
     FileUtils.cd('foo') do
       # Try with encoding = default encoding = utf-8
       File.open('content/index.html', 'w') { |io| io.write('Hello ' + 0xD6.chr + "!\n") }
-      exception = assert_raises(RuntimeError) do
+      exception = assert_raises(Nanoc::DataSources::Filesystem::Errors::InvalidEncoding) do
         Nanoc::Int::SiteLoader.new.new_from_cwd
       end
       assert_equal 'Could not read content/index.html because the file is not valid UTF-8.', exception.message
