@@ -1,4 +1,5 @@
+require 'helper'
+
 class Nanoc::CLI::LoggerTest < Nanoc::TestCase
-  def test_stub
-  end
+  def test_stub; end
 end
