@@ -1,3 +1,5 @@
+require 'helper'
+
 class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
   def new_data_source(params = nil)
     # Mock site
@@ -69,7 +71,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
   def test_load_objects_with_same_extensions
     # Create data source
-    data_source = new_data_source({ identifier_type: 'full' })
+    data_source = new_data_source(identifier_type: 'full')
 
     # Create a fake class
     klass = Class.new do
@@ -135,14 +137,14 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     File.open('foo/stuff.dat', 'w') { |io| io.write('random binary data') }
 
     # Load
-    assert_raises(RuntimeError) do
+    assert_raises(Nanoc::DataSources::Filesystem::Errors::BinaryLayout) do
       data_source.send(:load_objects, 'foo', Nanoc::Int::Layout)
     end
   end
 
   def test_identifier_for_filename_with_full_style_identifier
     # Create data source
-    data_source = new_data_source({ identifier_type: 'full' })
+    data_source = new_data_source(identifier_type: 'full')
 
     # Get input and expected output
     expected = {
@@ -463,7 +465,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
   end
 
   def test_load_objects_correct_identifier_with_separate_yaml_file
-    data_source = new_data_source({ identifier_type: 'full' })
+    data_source = new_data_source(identifier_type: 'full')
 
     FileUtils.mkdir_p('foo')
     File.write('foo/donkey.jpeg', 'data')
@@ -483,24 +485,6 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     assert_equal nil,            data_source.send(:filename_for, '/foo', nil)
   end
 
-  def test_compile_huge_site
-    if_implemented do
-      # Create data source
-      data_source = new_data_source
-
-      # Create a lot of items
-      count = Process.getrlimit(Process::RLIMIT_NOFILE)[0] + 5
-      count.times do |i|
-        FileUtils.mkdir_p("content/#{i}")
-        File.open("content/#{i}/#{i}.html", 'w') { |io| io << "This is item #{i}." }
-        File.open("content/#{i}/#{i}.yaml", 'w') { |io| io << "title: Item #{i}"   }
-      end
-
-      # Read all items
-      data_source.items
-    end
-  end
-
   def test_compile_iso_8859_1_site
     # Check encoding
     unless ''.respond_to?(:encode)
@@ -559,7 +543,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
   def test_all_split_files_in_allowing_periods_in_identifiers
     # Create data source
-    data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, { allow_periods_in_identifiers: true })
+    data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, allow_periods_in_identifiers: true)
 
     # Write sample files
     FileUtils.mkdir_p('foo')
@@ -660,14 +644,14 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     end
 
     # Check
-    assert_raises RuntimeError do
+    assert_raises(Nanoc::DataSources::Filesystem::Errors::MultipleContentFiles) do
       data_source.send(:all_split_files_in, '.')
     end
   end
 
   def test_basename_of_allowing_periods_in_identifiers
     # Create data source
-    data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, { allow_periods_in_identifiers: true })
+    data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, allow_periods_in_identifiers: true)
 
     # Get input and expected output
     expected = {
@@ -727,7 +711,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
   def test_ext_of_allowing_periods_in_identifiers
     # Create data source
-    data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, { allow_periods_in_identifiers: true })
+    data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, allow_periods_in_identifiers: true)
 
     # Get input and expected output
     expected = {
@@ -847,7 +831,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, nil)
 
     # Parse it
-    assert_raises(RuntimeError) do
+    assert_raises(Nanoc::DataSources::Filesystem::Errors::InvalidFormat) do
       data_source.instance_eval { parse('test.html', nil) }
     end
   end
@@ -999,7 +983,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, nil)
 
-    assert_raises(Nanoc::DataSources::Filesystem::InvalidMetadataError) do
+    assert_raises(Nanoc::DataSources::Filesystem::Errors::InvalidMetadata) do
       data_source.instance_eval { parse('test.html', nil) }
     end
   end
@@ -1010,7 +994,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     data_source = Nanoc::DataSources::Filesystem.new(nil, nil, nil, nil)
 
-    assert_raises(Nanoc::DataSources::Filesystem::InvalidMetadataError) do
+    assert_raises(Nanoc::DataSources::Filesystem::Errors::InvalidMetadata) do
       data_source.instance_eval { parse('test.html', 'test.yaml') }
     end
   end
