@@ -1,3 +1,5 @@
+require 'helper'
+
 class Nanoc::Filters::MustacheTest < Nanoc::TestCase
   def test_filter
     if_have 'mustache' do
@@ -9,7 +11,7 @@ class Nanoc::Filters::MustacheTest < Nanoc::TestCase
       )
 
       # Create filter
-      filter = ::Nanoc::Filters::Mustache.new({ item: item })
+      filter = ::Nanoc::Filters::Mustache.new(item: item)
 
       # Run filter
       result = filter.setup_and_run('The protagonist of {{title}} is {{protagonist}}.')
@@ -28,7 +30,7 @@ class Nanoc::Filters::MustacheTest < Nanoc::TestCase
 
       # Create filter
       filter = ::Nanoc::Filters::Mustache.new(
-        { content: 'No Payne No Gayne', item: item },
+        content: 'No Payne No Gayne', item: item,
       )
 
       # Run filter
