@@ -1,3 +1,5 @@
+require 'helper'
+
 class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
   def test_filter_html_with_double_quotes
     # Create filter with mock item
@@ -106,13 +108,13 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
   </body>
 </html>
 EOS
-    expected_match_0 = %r{<a href="\.\./\.\.">foo</a>}
-    expected_match_1 = %r{\A\s*<!DOCTYPE html\s*>\s*<html>\s*<head>(.|\s)*<title>Hello</title>\s*</head>\s*<body>\s*<a href="../..">foo</a>\s*</body>\s*</html>\s*\Z}m
+    expected0 = %r{<a href="\.\./\.\.">foo</a>}
+    expected1 = %r{\A\s*<!DOCTYPE html\s*>\s*<html>\s*<head>(.|\s)*<title>Hello</title>\s*</head>\s*<body>\s*<a href="../..">foo</a>\s*</body>\s*</html>\s*\Z}m
 
     # Test
     actual_content = filter.setup_and_run(raw_content, type: :html)
-    assert_match(expected_match_0, actual_content)
-    assert_match(expected_match_1, actual_content)
+    assert_match(expected0, actual_content)
+    assert_match(expected1, actual_content)
   end
 
   def test_filter_html_multiple
@@ -347,6 +349,32 @@ EOS
     assert_match(/<param (name="movie" )?content="..\/..\/example"/, actual_content)
   end
 
+  def test_filter_form
+    # Create filter with mock item
+    filter = Nanoc::Filters::RelativizePaths.new
+
+    # Mock item
+    filter.instance_eval do
+      @item_rep = Nanoc::Int::ItemRep.new(
+        Nanoc::Int::Item.new(
+          'content',
+          {},
+          '/foo/bar/baz/',
+        ),
+        :blah,
+      )
+      @item_rep.paths[:last] = '/foo/bar/baz/'
+    end
+
+    # Set content
+    raw_content      = %(<form action="/example"></form>)
+    expected_content = %(<form action="../../../example"></form>)
+
+    # Test
+    actual_content = filter.setup_and_run(raw_content, type: :html)
+    assert_equal(expected_content, actual_content)
+  end
+
   def test_filter_implicit
     # Create filter with mock item
     filter = Nanoc::Filters::RelativizePaths.new
