@@ -1,3 +1,5 @@
+require 'helper'
+
 class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
   include Nanoc::Helpers::Capturing
 
@@ -12,10 +14,15 @@ class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
       reps: item_rep_repo_for(item),
       items: :__irrelevant__,
       dependency_tracker: :__irrelevant__,
-      compiler: :__irrelevant__,
+      compilation_context: :__irrelevant__,
     )
   end
 
+  def before
+    super
+    Nanoc::CLI::ErrorHandler.enable
+  end
+
   def test_dependencies
     with_site do |_site|
       # Prepare
