@@ -1,3 +1,5 @@
+require 'helper'
+
 class Nanoc::RuleDSL::CompilerDSLTest < Nanoc::TestCase
   def test_compile
     # TODO: implement
@@ -290,7 +292,7 @@ EOS
   end
 
   def test_create_pattern_with_string_with_glob_string_pattern_type
-    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, { string_pattern_type: 'glob' })
+    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, string_pattern_type: 'glob')
 
     pattern = compiler_dsl.create_pattern('/foo/*')
     assert pattern.match?('/foo/aaaa')
@@ -299,14 +301,14 @@ EOS
   end
 
   def test_create_pattern_with_regex
-    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, { string_pattern_type: 'glob' })
+    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, string_pattern_type: 'glob')
 
     pattern = compiler_dsl.create_pattern(%r{\A/foo/a*/})
     assert pattern.match?('/foo/aaaa/')
   end
 
   def test_create_pattern_with_string_with_unknown_string_pattern_type
-    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, { string_pattern_type: 'donkey' })
+    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, string_pattern_type: 'donkey')
 
     err = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
       compiler_dsl.create_pattern('/foo/*')
@@ -319,7 +321,7 @@ EOS
     compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, {})
 
     actual   = compiler_dsl.instance_eval { identifier_to_regex('foo') }
-    expected = %r{^/foo/$}
+    expected = %r{^/foo/?$}
 
     assert_equal(expected.to_s,      actual.to_s)
     assert_equal(expected.source,    actual.source)
@@ -333,7 +335,7 @@ EOS
     compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, {})
 
     actual   = compiler_dsl.instance_eval { identifier_to_regex('foo/*/bar') }
-    expected = %r{^/foo/(.*?)/bar/$}
+    expected = %r{^/foo/(.*?)/bar/?$}
 
     assert_equal(expected.to_s,      actual.to_s)
     assert_equal(expected.source,    actual.source)
@@ -347,7 +349,7 @@ EOS
     compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, {})
 
     actual   = compiler_dsl.instance_eval { identifier_to_regex('foo/*/bar/*/qux') }
-    expected = %r{^/foo/(.*?)/bar/(.*?)/qux/$}
+    expected = %r{^/foo/(.*?)/bar/(.*?)/qux/?$}
 
     assert_equal(expected.to_s,      actual.to_s)
     assert_equal(expected.source,    actual.source)
@@ -403,7 +405,7 @@ EOS
     compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, {})
 
     actual   = compiler_dsl.instance_eval { identifier_to_regex('/foo/+') }
-    expected = %r{^/foo/(.+?)/$}
+    expected = %r{^/foo/(.+?)/?$}
 
     assert_equal(expected.to_s,      actual.to_s)
     assert_equal(expected.source,    actual.source)
@@ -414,6 +416,20 @@ EOS
     refute('/foo/' =~ actual)
   end
 
+  def test_identifier_to_regex_with_full_identifier
+    # Create compiler DSL
+    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, {})
+
+    actual   = compiler_dsl.instance_eval { identifier_to_regex('/favicon.ico') }
+    expected = %r{^/favicon\.ico/?$}
+
+    assert_equal(expected.to_s, actual.to_s)
+
+    assert('/favicon.ico' =~ actual)
+    assert('/favicon.ico/' =~ actual)
+    refute('/faviconxico' =~ actual)
+  end
+
   def test_dsl_has_no_access_to_compiler
     compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, {})
     assert_raises(NameError) do
@@ -423,7 +439,7 @@ EOS
 
   def test_config
     $venetian = 'unsnares'
-    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, { venetian: 'snares' })
+    compiler_dsl = Nanoc::RuleDSL::CompilerDSL.new(nil, venetian: 'snares')
     compiler_dsl.instance_eval { $venetian = @config[:venetian] }
     assert_equal 'snares', $venetian
   end
